# myrcella

[![](https://img.shields.io/pypi/v/myrcella?style=for-the-badge)](https://pypi.org/project/myrcella/)
[![](https://img.shields.io/pypi/dm/myrcella?style=for-the-badge)](https://pypi.org/project/myrcella/)
[![](https://img.shields.io/github/stars/krateng/myrcella?style=for-the-badge&color=purple)](https://github.com/krateng/myrcella/stargazers)
[![](https://img.shields.io/pypi/l/myrcella?style=for-the-badge)](https://github.com/krateng/myrcella/blob/master/LICENSE)

Myrcella is a simple webserver to collect data that can be specified with yaml files.

Install with `pip install myrcella`.
